diff --git a/builder/dockerfile/dispatchers.go b/builder/dockerfile/dispatchers.go
index 42a36d66c2..e10bb32594 100644
--- a/builder/dockerfile/dispatchers.go
+++ b/builder/dockerfile/dispatchers.go
@@ -447,7 +447,7 @@ func cmd(b *Builder, args []string, attributes map[string]bool, original string)
 }
 
 // parseOptInterval(flag) is the duration of flag.Value, or 0 if
 // empty. An error is reported if the value is given and is not positive.
 func parseOptInterval(f *Flag) (time.Duration, error) {
 	s := f.Value
 	if s == "" {
@@ -457,8 +457,8 @@ func parseOptInterval(f *Flag) (time.Duration, error) {
 	if err != nil {
 		return 0, err
 	}
-	if d <= 0 {
-		return 0, fmt.Errorf("Interval %#v must be positive", f.name)
+	if d < time.Duration(time.Second) {
+		return 0, fmt.Errorf("Interval %#v cannot be less than 1 second", f.name)
 	}
 	return d, nil
 }
@@ -447,7 +447,7 @@ func cmd(b *Builder, args []string, attributes map[string]bool, original string)
 
 // parseOptInterval(flag) is the duration of flag.Value, or 0 if
-// empty. An error is reported if the value is given and is not positive.
+// empty. An error is reported if the value is given and less than 1 second.
 func parseOptInterval(f *Flag) (time.Duration, error) {
 	s := f.Value